@@ -63,7 +63,7 @@ def cast(df, target_col, value):
 def create_row(): # might not be needed, if so it will be a create row with filter and col_ops
     pass
 
-def bucket(df, column, bucket_col_name, intervals):
+def bucket(df, column, bucket_col_name, intervals): # need to add in operand for both lower and upper bounds
     interval_values = []
     for value in df[column]:
         interval = 'other'
@@ -77,6 +77,7 @@ def bucket(df, column, bucket_col_name, intervals):
     return df
 
 def date_format(df, target_col, date_format):
-    df[target_col] = pd.to_datetime(df[target_col], format=date_format)
+    df[target_col] = pd.to_datetime(df[target_col])
+    df[target_col] = df[target_col].dt.strftime(date_format)
     return df
 
